Task: MCTest
=============
Description: Questions about short children's stories, from Richardson et al. '13. 

Link: https://www.microsoft.com/en-us/research/publication/mctest-challenge-dataset-open-domain-machine-comprehension-text/

Tags: #MCTest, #All, #QA

